#ifndef HAL_PROTO_H_
#define HAL_PROTO_H_

#define	HAL_PACKET_MAX		4096
#define HAL_STRING_MAX		256

/*
 * 9 - length of PROTO_MAGIC.
 * 2 - command name.
 * 3 - subcommand name.
 * 8 - length of payload, we take 4 bytes (8 ascii symbols).
 * 5 - '\n' one for each string plus the header end.
 */

#define HAL_HEADER_MAX		(9 + 2 + 3 + 8 + 5)
#define	HAL_PAYLOAD_MAX		(HAL_PACKET_MAX - HAL_HEADER_MAX)
/*
 * When we recieve or send packet an image field a packet looks
 * the following way:
 *
 * 2 - length of OK
 * 8 - image offset
 * 3 - '\n' one for each string
 */
#define	HAL_IMAGE_MAX		(HAL_PAYLOAD_MAX - 2 - 8 - 3)
//#define HAL_IMAGE_MAX		2

/* Each packet has a header that starts with the magic. */
#define	HAL_PROTO_MAGIC		"HAL_PROTO"
/* HAL protocol version, these numbers are checked during connection. */
#define	HAL_PROTO_MAJOR		0
#define	HAL_PROTO_MINOR		1

#define	HAL_CMD_CONNECT		hal_cmd_connect
#define	HAL_CMD_DISCONNECT	hal_cmd_disconnect
#define	HAL_CMD_CYCLE_BEGIN	hal_cmd_cycle_begin
#define	HAL_CMD_CYCLE_RUN	hal_cmd_cycle_run
#define	HAL_CMD_CYCLE_END	hal_cmd_cycle_end
#define HAL_CMD_WRITE_INPUTS	hal_cmd_write_inputs
#define HAL_CMD_WRITE_OUTPUTS	hal_cmd_write_outputs
#define HAL_CMD_WRITE_PREPARE	hal_cmd_write_prepare
#define HAL_CMD_WRITE_END	hal_cmd_write_end
#define HAL_CMD_READ_INPUTS	hal_cmd_read_inputs
#define HAL_CMD_READ_OUTPUTS	hal_cmd_read_outputs
#define HAL_CMD_READ_PREPARE	hal_cmd_read_prepare
#define	HAL_CMD_READ_END	hal_cmd_read_end

#define HAL_SUBCMD_REQUEST	hal_subcmd_request
#define HAL_SUBCMD_REPLY	hal_subcmd_reply

#define HAL_OK			hal_status_ok
#define HAL_ERR			hal_status_error

extern const char const *hal_cmd_connect;
extern const char const *hal_cmd_disconnect;
extern const char const *hal_cmd_cycle_begin;
extern const char const *hal_cmd_cycle_run;
extern const char const *hal_cmd_cycle_end;
extern const char const *hal_cmd_write_inputs;
extern const char const *hal_cmd_write_outputs;
extern const char const *hal_cmd_write_prepare;
extern const char const *hal_cmd_write_end;
extern const char const *hal_cmd_read_inputs;
extern const char const *hal_cmd_read_outputs;
extern const char const *hal_cmd_read_prepare;
extern const char const *hal_cmd_read_end;

extern const char const *hal_subcmd_request;
extern const char const *hal_subcmd_reply;

extern const char const *hal_status_ok;
extern const char const *hal_status_error;

#endif
